@@ -27,19 +27,20 @@ This plugin enables L<DBIx::Class::Schema::Versioned/backup> when using MySQL.
 
 =cut
 
+package DBIx::Class::Storage::DBI::mysql::backup;
+
 use strict;
 use warnings;
 
 use DBIx::Class::Storage::DBI;
-use DateTime;
 use MySQL::Backup;
 use File::Path qw/mkpath/;
 use Symbol;
 
 use vars qw( $VERSION );
-$VERSION = '0.01';
+$VERSION = '0.02';
 
-BEGIN {
+sub import {
 
     *DBIx::Class::Storage::DBI::dump = \&_dump;
     *DBIx::Class::Storage::DBI::backup = \&_backup;
